<?php

/**
 * YITH WooCommerce Dynamic Pricing and Discounts plugin support
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

if (!class_exists('AWL_Yith_Discounts')) :

    /**
     * Class for main plugin functions
     */
    class AWL_Yith_Discounts
    {

        /**
         * @var AWL_Yith_Discounts The single instance of the class
         */
        protected static $_instance = null;

        /**
         * Main AWL_Yith_Discounts Instance
         *
         * Ensures only one instance of AWL_Yith_Discounts is loaded or can be loaded.
         *
         * @static
         * @return AWL_Yith_Discounts - Main instance
         */
        public static function instance() {
            if (is_null(self::$_instance)) {
                self::$_instance = new self();
            }
            return self::$_instance;
        }

        /*
         * Constructor
         */
        public function __construct() {

            add_filter( 'awl_product_sale_price', array( $this, 'awl_product_sale_price' ), 1, 2 );

            add_filter( 'awl_is_on_sale', array( $this, 'awl_is_on_sale' ), 1, 2 );

        }

        /*
         * Get discounted price
         */
        public function awl_product_sale_price( $sale_price, $product  ) {

            if ( ! $sale_price ) {
                $yith_sale_price = $this->get_yith_discount( $product );
                if ( $yith_sale_price ) {
                    $sale_price = $yith_sale_price;
                }
            }

            return $sale_price;

        }

        /*
        * Get product sale status
        */
        public function awl_is_on_sale( $is_on_sale, $product  ) {
            if ( ! $is_on_sale ) {
                $yith_sale_price = $this->get_yith_discount( $product );
                if ( $yith_sale_price ) {
                    $is_on_sale = true;
                }
            }
            return $is_on_sale;
        }

        /*
        * Yith discounted price
        */
        private function get_yith_discount( $product ) {

            $sale_price = false;
            $price_html = $product->get_price_html();
            $regular_price = $product->get_price();

            if ( $product->is_type( 'variable' ) ) {
                $regex = '/(\d+([\.|,]\d{1,2})?).*?-/i';
            } else {
                $regex = '/(\d+([\.|,]\d{1,2})?)/i';
            }

            if ( preg_match_all( $regex, $price_html, $matches ) ) {
                if ( isset( $matches[1][0] ) && $matches[1][0] != $regular_price ) {
                    $sale_price = $matches[1][0];
                } elseif ( isset( $matches[1][1] ) && $matches[1][1] != $regular_price ) {
                    $sale_price = $matches[1][1];
                }
            }

            return $sale_price;

        }


    }

endif;

AWL_Yith_Discounts::instance();